@@ -1,5 +1,5 @@
 package Net::Twitter;
-$Net::Twitter::VERSION = '4.01008';
+$Net::Twitter::VERSION = '4.01009';
 use Moose;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use JSON;
@@ -119,8 +119,11 @@ sub new {
 
     $traits ||= [ qw/Legacy/ ];
 
-    # ensure we have the OAuth trait if we have a consumer key
-    $traits = [ (grep $_ ne 'OAuth', @$traits), 'OAuth' ] if $args{consumer_key};
+    # ensure we have the OAuth trait if we have a consumer key (unless we've
+    # specified AppAuth)
+    if ( $args{consumer_key} && !grep $_ eq 'AppAuth', @$traits ) {
+        $traits = [ (grep $_ ne 'OAuth', @$traits), 'OAuth' ];
+    }
 
     # create a unique name for the created class based on trait names and parameters
     my $anon_class_name = _name_for_anon_class($traits);
@@ -157,7 +160,7 @@ Net::Twitter - A perl interface to the Twitter API
 
 =head1 VERSION
 
-version 4.01008
+version 4.01009
 
 =head1 DESCRIPTION
 
