@@ -1,6 +1,6 @@
 package Net::Twitter::Core;
 
-our $VERSION = '4.01008';
+our $VERSION = '4.01009';
 
 # ABSTRACT: A perl interface to the Twitter API
 
@@ -39,7 +39,7 @@ has _base_url       => ( is => 'rw' ); ### keeps role composition from bitching
 has _json_handler   => (
     is      => 'rw',
     default => sub { JSON->new->utf8 },
-    handles => { _from_json => 'decode' },
+    handles => { from_json => 'decode' },
 );
 
 sub _legacy_synthetic_args { qw/authenticate since/ }
@@ -250,7 +250,7 @@ sub _parse_result {
     my $content = $res->content;
     $content =~ s/^"(true|false)"$/$1/;
 
-    my $obj = try { $self->_from_json($content) };
+    my $obj = try { $self->from_json($content) };
     $self->_decode_html_entities($obj) if $obj && $self->decode_html_entities;
 
     # filter before inflating objects
@@ -355,7 +355,7 @@ Net::Twitter::Core - Net::Twitter implementation
 
 =head1 VERSION
 
-version 4.01008
+version 4.01009
 
 =head1 SYNOPSIS
 
