@@ -1,5 +1,5 @@
 package Net::Twitter::Role::API::Search;
-$Net::Twitter::Role::API::Search::VERSION = '4.01008';
+$Net::Twitter::Role::API::Search::VERSION = '4.01009';
 use Moose::Role;
 use Net::Twitter::API;
 use DateTime::Format::Strptime;
@@ -28,6 +28,8 @@ C<next_page>, C<refresh_url>, and C<max_id>. The statuses are returned in
 C<results>.  To iterate over the results, use something similar to:
 
     my $r = $nt->search($search_term);
+    my $r = $nt->search({ q => $search_term, count => 10 })
+
     for my $status ( @{$r->{results}} ) {
         print "$status->{text}\n";
     }
@@ -35,7 +37,7 @@ EOT
 
     path     => 'search',
     method   => 'GET',
-    params   => [qw/q callback lang locale rpp page since_id until geocode show_user result_type/],
+    params   => [qw/q geocode lang locale result_type count until since_id max_id include_entities callback/],
     required => [qw/q/],
     returns  => 'HashRef',
 );
@@ -50,7 +52,7 @@ Net::Twitter::Role::API::Search - A definition of the Twitter Search API as a Mo
 
 =head1 VERSION
 
-version 4.01008
+version 4.01009
 
 =head1 SYNOPSIS
 
